@@ -13,11 +13,11 @@ WWW::Sitebase::Navigator - Base class for modules that navigate web sites
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -262,7 +262,7 @@ not be used.
 Really only useful as an option passed to the "new" method when
 creating a new object.
 
- # Don't log in, just create a new object
+ # Create a new object and prompt the user to log in.
  my $site = new WWW::MySite( auto_login => 1 );
 
 =cut
@@ -398,7 +398,7 @@ sub site_login {
     return undef if $self->error;
 
     # Load the home page.
-    $self->_go_home;
+#     $self->_go_home;
 
     # Verify we're logged in
     if ( ( ! $verify_re ) ||
@@ -681,11 +681,11 @@ sub ____CHECK_STATUS____ {}
 =head2 logged_in
 
 Returns true if login was successful. When you call the new method
-of WWW::Bebo, the class logs in using the username and password you
-provided (or that it prompted for).  It then retreives your "home"
-page (the one you see when you click the "Home" button on bebo.com,
-and checks it against an RE.  If the page matches the RE, logged_in is
-set to a true value. Otherwise it's set to a false value.
+of WWW::Sitebase::Navigator, the class logs in using the username and password
+you provided (or that it prompted for).  It then retreives your "home"
+page (the one you see when you click the "Home" button that's set up in your
+site_info field), and checks it against an RE.  If the page matches the RE,
+logged_in is set to a true value. Otherwise it's set to a false value.
 
  Notes:
  - This method is only set on login. If you're logged out somehow,
@@ -695,14 +695,15 @@ set to a true value. Otherwise it's set to a false value.
    it, but that would be stupid, and it might not work later
    anyway, so don't.
 
- Examples:
+ Examples, pretending we have a subclass named WWW::Bebo to navigate a site
+ named bebo.com:
 
  my $bebo = new WWW::Bebo;
  unless ( $site->logged_in ) {
     die "Login failed\n";
  }
  
- # This will try forever to log in
+ # This will log you in, looping forever until it succeeds.
  my $bebo;
 
  do {
